@@ -170,7 +170,13 @@ void PreferencesDialog::init() {
     fontPageLayout->addStretch();
     fontPage->setLayout( fontPageLayout );
 
+#if defined(Q_WS_HILDON)
+    interfacePage = new QScrollArea();
+    //interfacePage->setWidgetResizable( true );
+    interfacePageBox = new QWidget();
+#else
     interfacePage = new QWidget();
+#endif
 
     miscInterfaceOptionsPanel = new QWidget();
     miscInterfaceOptionsPanelLayout = new QGridLayout();
@@ -208,6 +214,7 @@ void PreferencesDialog::init() {
 
     keyboardAccelListView = new QTreeWidget();
     keyboardAccelListView->setColumnCount( 2 );
+    keyboardAccelListView->setMinimumWidth( 700 );
     QStringList headerLabels;
     headerLabels << tr( "Action" ) << tr( "Key" ); 
     keyboardAccelListView->setHeaderLabels( headerLabels );
@@ -241,9 +248,15 @@ void PreferencesDialog::init() {
     connect( setAccelKeyButton, SIGNAL( clicked() ), this, SLOT( setAccelKey() ) );
     connect( resetAccelKeyButton, SIGNAL( clicked() ), this, SLOT( resetAccelKey() ) );
 
-    interfacePageLayout = new QVBoxLayout( interfacePage );
+    interfacePageLayout = new QVBoxLayout();
     interfacePageLayout->addWidget( miscInterfaceOptionsPanel );
     interfacePageLayout->addWidget( keyboardAccelPanel, 1 );
+#if defined(Q_WS_HILDON)
+    interfacePageBox->setLayout( interfacePageLayout );
+    interfacePage->setWidget( interfacePageBox );
+#else
+    interfacePage->setLayout( interfacePageLayout );
+#endif
 
     languagePage = new QWidget();
 
